"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the airflow_clickhouse_plugin package.
"""

__title__ = 'airflow-clickhouse-plugin'
__description__ = \
    'airflow-clickhouse-plugin - ' \
    'Airflow plugin to execute ClickHouse commands and queries'
__version__ = '0.5.1'
__author__ = 'Viktor Taranenko'
__author_email__ = 'viktor@samsungnext.com'
__license__ = 'MIT License'
__url__ = 'https://github.com/whisklabs/airflow-clickhouse-plugin'
